#[repr(C)]pub struct Address {
pub bus: u8,
pub device: u8,
pub function: u8,
}Expand description
An address of a PCI device.
Fields
bus: u8device: u8function: u8Trait Implementations
Sourceimpl<'a, ___E> Encode<Address, ___E> for &'a Addresswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Address, ___E> for &'a Addresswhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Address, ___E> for Addresswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Address, ___E> for Addresswhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Address>
const COPY_OPTIMIZATION: CopyOptimization<Self, Address>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Address>, ___E> for &'a Address
impl<'a, ___E> EncodeOption<Box<'static, Address>, ___E> for &'a Address
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Address>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Address>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Address>, ___E> for Address
impl<___E> EncodeOption<Box<'static, Address>, ___E> for Address
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Address>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Address>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Address> for Address
impl FromWireRef<Address> for Address
Sourcefn from_wire_ref(wire: &Address) -> Self
fn from_wire_ref(wire: &Address) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Address
impl Ord for Address
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Address
impl PartialOrd for Address
impl Copy for Address
impl Eq for Address
impl StructuralPartialEq for Address