pub struct BusGetDevicesResponse {
pub devices: Vec<PciDevice>,
}Fields
devices: Vec<PciDevice>Trait Implementations
Sourceimpl Clone for BusGetDevicesResponse
impl Clone for BusGetDevicesResponse
Sourcefn clone(&self) -> BusGetDevicesResponse
fn clone(&self) -> BusGetDevicesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BusGetDevicesResponse
impl Debug for BusGetDevicesResponse
Sourceimpl<'a, ___E> Encode<BusGetDevicesResponse<'static>, ___E> for &'a BusGetDevicesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<BusGetDevicesResponse<'static>, ___E> for &'a BusGetDevicesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BusGetDevicesResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BusGetDevicesResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BusGetDevicesResponse<'static>, ___E> for BusGetDevicesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<BusGetDevicesResponse<'static>, ___E> for BusGetDevicesResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BusGetDevicesResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BusGetDevicesResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BusGetDevicesResponse<'static>>, ___E> for &'a BusGetDevicesResponsewhere
___E: Encoder + ?Sized,
&'a BusGetDevicesResponse: Encode<BusGetDevicesResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, BusGetDevicesResponse<'static>>, ___E> for &'a BusGetDevicesResponsewhere
___E: Encoder + ?Sized,
&'a BusGetDevicesResponse: Encode<BusGetDevicesResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BusGetDevicesResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BusGetDevicesResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BusGetDevicesResponse<'static>>, ___E> for BusGetDevicesResponse
impl<___E> EncodeOption<Box<'static, BusGetDevicesResponse<'static>>, ___E> for BusGetDevicesResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BusGetDevicesResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BusGetDevicesResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<BusGetDevicesResponse<'de>> for BusGetDevicesResponse
impl<'de> FromWire<BusGetDevicesResponse<'de>> for BusGetDevicesResponse
Sourcefn from_wire(wire: BusGetDevicesResponse<'de>) -> Self
fn from_wire(wire: BusGetDevicesResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<BusGetDevicesResponse<'de>> for BusGetDevicesResponse
impl<'de> FromWireRef<BusGetDevicesResponse<'de>> for BusGetDevicesResponse
Sourcefn from_wire_ref(wire: &BusGetDevicesResponse<'de>) -> Self
fn from_wire_ref(wire: &BusGetDevicesResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for BusGetDevicesResponse
impl Hash for BusGetDevicesResponse
Sourceimpl Ord for BusGetDevicesResponse
impl Ord for BusGetDevicesResponse
Sourcefn cmp(&self, other: &BusGetDevicesResponse) -> Ordering
fn cmp(&self, other: &BusGetDevicesResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BusGetDevicesResponse
impl PartialEq for BusGetDevicesResponse
Sourcefn eq(&self, other: &BusGetDevicesResponse) -> bool
fn eq(&self, other: &BusGetDevicesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BusGetDevicesResponse
impl PartialOrd for BusGetDevicesResponse
impl Eq for BusGetDevicesResponse
impl StructuralPartialEq for BusGetDevicesResponse