#[repr(C)]pub struct DeviceGetBarRequest {
pub bar_id: u32,
}Fields
bar_id: u32Trait Implementations
Sourceimpl Clone for DeviceGetBarRequest
impl Clone for DeviceGetBarRequest
Sourcefn clone(&self) -> DeviceGetBarRequest
fn clone(&self) -> DeviceGetBarRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetBarRequest
impl Debug for DeviceGetBarRequest
Sourceimpl<'a, ___E> Encode<DeviceGetBarRequest, ___E> for &'a DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetBarRequest, ___E> for &'a DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBarRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBarRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetBarRequest, ___E> for DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetBarRequest, ___E> for DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBarRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBarRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBarRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBarRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetBarRequest>, ___E> for &'a DeviceGetBarRequest
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetBarRequest>, ___E> for &'a DeviceGetBarRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBarRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBarRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetBarRequest>, ___E> for DeviceGetBarRequest
impl<___E> EncodeOption<Box<'static, DeviceGetBarRequest>, ___E> for DeviceGetBarRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBarRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBarRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetBarRequest> for DeviceGetBarRequest
impl FromWire<DeviceGetBarRequest> for DeviceGetBarRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBarRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBarRequest, Self>
Sourcefn from_wire(wire: DeviceGetBarRequest) -> Self
fn from_wire(wire: DeviceGetBarRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetBarRequest> for DeviceGetBarRequest
impl FromWireRef<DeviceGetBarRequest> for DeviceGetBarRequest
Sourcefn from_wire_ref(wire: &DeviceGetBarRequest) -> Self
fn from_wire_ref(wire: &DeviceGetBarRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetBarRequest
impl Hash for DeviceGetBarRequest
Sourceimpl Ord for DeviceGetBarRequest
impl Ord for DeviceGetBarRequest
Sourcefn cmp(&self, other: &DeviceGetBarRequest) -> Ordering
fn cmp(&self, other: &DeviceGetBarRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetBarRequest
impl PartialEq for DeviceGetBarRequest
Sourcefn eq(&self, other: &DeviceGetBarRequest) -> bool
fn eq(&self, other: &DeviceGetBarRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetBarRequest
impl PartialOrd for DeviceGetBarRequest
impl Copy for DeviceGetBarRequest
impl Eq for DeviceGetBarRequest
impl StructuralPartialEq for DeviceGetBarRequest