#[repr(C)]pub struct DeviceGetBtiRequest {
pub index: u32,
}Fields
index: u32Trait Implementations
Sourceimpl Clone for DeviceGetBtiRequest
impl Clone for DeviceGetBtiRequest
Sourcefn clone(&self) -> DeviceGetBtiRequest
fn clone(&self) -> DeviceGetBtiRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetBtiRequest
impl Debug for DeviceGetBtiRequest
Sourceimpl<'a, ___E> Encode<DeviceGetBtiRequest, ___E> for &'a DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetBtiRequest, ___E> for &'a DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetBtiRequest, ___E> for DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetBtiRequest, ___E> for DeviceGetBtiRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetBtiRequest>, ___E> for &'a DeviceGetBtiRequest
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetBtiRequest>, ___E> for &'a DeviceGetBtiRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBtiRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBtiRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetBtiRequest>, ___E> for DeviceGetBtiRequest
impl<___E> EncodeOption<Box<'static, DeviceGetBtiRequest>, ___E> for DeviceGetBtiRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBtiRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBtiRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetBtiRequest> for DeviceGetBtiRequest
impl FromWire<DeviceGetBtiRequest> for DeviceGetBtiRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiRequest, Self>
Sourcefn from_wire(wire: DeviceGetBtiRequest) -> Self
fn from_wire(wire: DeviceGetBtiRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetBtiRequest> for DeviceGetBtiRequest
impl FromWireRef<DeviceGetBtiRequest> for DeviceGetBtiRequest
Sourcefn from_wire_ref(wire: &DeviceGetBtiRequest) -> Self
fn from_wire_ref(wire: &DeviceGetBtiRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetBtiRequest
impl Hash for DeviceGetBtiRequest
Sourceimpl Ord for DeviceGetBtiRequest
impl Ord for DeviceGetBtiRequest
Sourcefn cmp(&self, other: &DeviceGetBtiRequest) -> Ordering
fn cmp(&self, other: &DeviceGetBtiRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetBtiRequest
impl PartialEq for DeviceGetBtiRequest
Sourcefn eq(&self, other: &DeviceGetBtiRequest) -> bool
fn eq(&self, other: &DeviceGetBtiRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetBtiRequest
impl PartialOrd for DeviceGetBtiRequest
impl Copy for DeviceGetBtiRequest
impl Eq for DeviceGetBtiRequest
impl StructuralPartialEq for DeviceGetBtiRequest