#[repr(C)]pub struct DeviceGetInterruptModesResponse {
pub modes: InterruptModes,
}Fields
modes: InterruptModesTrait Implementations
Sourceimpl Clone for DeviceGetInterruptModesResponse
impl Clone for DeviceGetInterruptModesResponse
Sourcefn clone(&self) -> DeviceGetInterruptModesResponse
fn clone(&self) -> DeviceGetInterruptModesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<DeviceGetInterruptModesResponse, ___E> for &'a DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetInterruptModesResponse, ___E> for &'a DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetInterruptModesResponse, ___E> for DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetInterruptModesResponse, ___E> for DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptModesResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptModesResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetInterruptModesResponse>, ___E> for &'a DeviceGetInterruptModesResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetInterruptModesResponse: Encode<DeviceGetInterruptModesResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetInterruptModesResponse>, ___E> for &'a DeviceGetInterruptModesResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetInterruptModesResponse: Encode<DeviceGetInterruptModesResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetInterruptModesResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetInterruptModesResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetInterruptModesResponse>, ___E> for DeviceGetInterruptModesResponsewhere
___E: Encoder + ?Sized,
DeviceGetInterruptModesResponse: Encode<DeviceGetInterruptModesResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetInterruptModesResponse>, ___E> for DeviceGetInterruptModesResponsewhere
___E: Encoder + ?Sized,
DeviceGetInterruptModesResponse: Encode<DeviceGetInterruptModesResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetInterruptModesResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetInterruptModesResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
impl FromWire<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptModesResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptModesResponse, Self>
Sourcefn from_wire(wire: DeviceGetInterruptModesResponse) -> Self
fn from_wire(wire: DeviceGetInterruptModesResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
impl FromWireRef<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
Sourcefn from_wire_ref(wire: &DeviceGetInterruptModesResponse) -> Self
fn from_wire_ref(wire: &DeviceGetInterruptModesResponse) -> Self
Converts the given reference to this type.
Sourceimpl Ord for DeviceGetInterruptModesResponse
impl Ord for DeviceGetInterruptModesResponse
Sourcefn cmp(&self, other: &DeviceGetInterruptModesResponse) -> Ordering
fn cmp(&self, other: &DeviceGetInterruptModesResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetInterruptModesResponse
impl PartialEq for DeviceGetInterruptModesResponse
Sourcefn eq(&self, other: &DeviceGetInterruptModesResponse) -> bool
fn eq(&self, other: &DeviceGetInterruptModesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetInterruptModesResponse
impl PartialOrd for DeviceGetInterruptModesResponse
impl Copy for DeviceGetInterruptModesResponse
impl Eq for DeviceGetInterruptModesResponse
impl StructuralPartialEq for DeviceGetInterruptModesResponse