#[repr(C)]pub struct DeviceReadConfig16Response {
pub value: u16,
}Fields
value: u16Trait Implementations
Sourceimpl Clone for DeviceReadConfig16Response
impl Clone for DeviceReadConfig16Response
Sourcefn clone(&self) -> DeviceReadConfig16Response
fn clone(&self) -> DeviceReadConfig16Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceReadConfig16Response
impl Debug for DeviceReadConfig16Response
Sourceimpl<'a, ___E> Encode<DeviceReadConfig16Response, ___E> for &'a DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig16Response, ___E> for &'a DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig16Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig16Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig16Response, ___E> for DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig16Response, ___E> for DeviceReadConfig16Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig16Response>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig16Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig16Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig16Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceReadConfig16Response>, ___E> for &'a DeviceReadConfig16Responsewhere
___E: Encoder + ?Sized,
&'a DeviceReadConfig16Response: Encode<DeviceReadConfig16Response, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceReadConfig16Response>, ___E> for &'a DeviceReadConfig16Responsewhere
___E: Encoder + ?Sized,
&'a DeviceReadConfig16Response: Encode<DeviceReadConfig16Response, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadConfig16Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadConfig16Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceReadConfig16Response>, ___E> for DeviceReadConfig16Response
impl<___E> EncodeOption<Box<'static, DeviceReadConfig16Response>, ___E> for DeviceReadConfig16Response
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceReadConfig16Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceReadConfig16Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceReadConfig16Response> for DeviceReadConfig16Response
impl FromWire<DeviceReadConfig16Response> for DeviceReadConfig16Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig16Response, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig16Response, Self>
Sourcefn from_wire(wire: DeviceReadConfig16Response) -> Self
fn from_wire(wire: DeviceReadConfig16Response) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig16Response> for DeviceReadConfig16Response
impl FromWireRef<DeviceReadConfig16Response> for DeviceReadConfig16Response
Sourcefn from_wire_ref(wire: &DeviceReadConfig16Response) -> Self
fn from_wire_ref(wire: &DeviceReadConfig16Response) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceReadConfig16Response
impl Hash for DeviceReadConfig16Response
Sourceimpl Ord for DeviceReadConfig16Response
impl Ord for DeviceReadConfig16Response
Sourcefn cmp(&self, other: &DeviceReadConfig16Response) -> Ordering
fn cmp(&self, other: &DeviceReadConfig16Response) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceReadConfig16Response
impl PartialEq for DeviceReadConfig16Response
Sourcefn eq(&self, other: &DeviceReadConfig16Response) -> bool
fn eq(&self, other: &DeviceReadConfig16Response) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceReadConfig16Response
impl PartialOrd for DeviceReadConfig16Response
impl Copy for DeviceReadConfig16Response
impl Eq for DeviceReadConfig16Response
impl StructuralPartialEq for DeviceReadConfig16Response