#[repr(C)]pub struct ExtendedCapability {
pub id: u16,
pub offset: u16,
}Fields
id: u16offset: u16Trait Implementations
Sourceimpl Clone for ExtendedCapability
impl Clone for ExtendedCapability
Sourcefn clone(&self) -> ExtendedCapability
fn clone(&self) -> ExtendedCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtendedCapability
impl Debug for ExtendedCapability
Sourceimpl<'a, ___E> Encode<ExtendedCapability, ___E> for &'a ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ExtendedCapability, ___E> for &'a ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ExtendedCapability>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ExtendedCapability>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ExtendedCapability, ___E> for ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ExtendedCapability, ___E> for ExtendedCapabilitywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ExtendedCapability>
const COPY_OPTIMIZATION: CopyOptimization<Self, ExtendedCapability>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ExtendedCapability>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ExtendedCapability>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ExtendedCapability>, ___E> for &'a ExtendedCapability
impl<'a, ___E> EncodeOption<Box<'static, ExtendedCapability>, ___E> for &'a ExtendedCapability
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ExtendedCapability>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ExtendedCapability>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ExtendedCapability>, ___E> for ExtendedCapability
impl<___E> EncodeOption<Box<'static, ExtendedCapability>, ___E> for ExtendedCapability
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ExtendedCapability>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ExtendedCapability>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ExtendedCapability> for ExtendedCapability
impl FromWire<ExtendedCapability> for ExtendedCapability
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ExtendedCapability, Self>
const COPY_OPTIMIZATION: CopyOptimization<ExtendedCapability, Self>
Sourcefn from_wire(wire: ExtendedCapability) -> Self
fn from_wire(wire: ExtendedCapability) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ExtendedCapability> for ExtendedCapability
impl FromWireRef<ExtendedCapability> for ExtendedCapability
Sourcefn from_wire_ref(wire: &ExtendedCapability) -> Self
fn from_wire_ref(wire: &ExtendedCapability) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ExtendedCapability
impl Hash for ExtendedCapability
Sourceimpl Ord for ExtendedCapability
impl Ord for ExtendedCapability
Sourcefn cmp(&self, other: &ExtendedCapability) -> Ordering
fn cmp(&self, other: &ExtendedCapability) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtendedCapability
impl PartialEq for ExtendedCapability
Sourcefn eq(&self, other: &ExtendedCapability) -> bool
fn eq(&self, other: &ExtendedCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ExtendedCapability
impl PartialOrd for ExtendedCapability
impl Copy for ExtendedCapability
impl Eq for ExtendedCapability
impl StructuralPartialEq for ExtendedCapability