pub struct HostBridgeInfo {
pub name: String,
pub start_bus_number: u8,
pub end_bus_number: u8,
pub segment_group: u16,
}Fields
name: Stringstart_bus_number: u8end_bus_number: u8segment_group: u16Trait Implementations
Sourceimpl Clone for HostBridgeInfo
impl Clone for HostBridgeInfo
Sourcefn clone(&self) -> HostBridgeInfo
fn clone(&self) -> HostBridgeInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HostBridgeInfo
impl Debug for HostBridgeInfo
Sourceimpl<'a, ___E> Encode<HostBridgeInfo<'static>, ___E> for &'a HostBridgeInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<HostBridgeInfo<'static>, ___E> for &'a HostBridgeInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HostBridgeInfo<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HostBridgeInfo<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<HostBridgeInfo<'static>, ___E> for HostBridgeInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<HostBridgeInfo<'static>, ___E> for HostBridgeInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HostBridgeInfo<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HostBridgeInfo<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, HostBridgeInfo<'static>>, ___E> for &'a HostBridgeInfo
impl<'a, ___E> EncodeOption<Box<'static, HostBridgeInfo<'static>>, ___E> for &'a HostBridgeInfo
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, HostBridgeInfo<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, HostBridgeInfo<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, HostBridgeInfo<'static>>, ___E> for HostBridgeInfo
impl<___E> EncodeOption<Box<'static, HostBridgeInfo<'static>>, ___E> for HostBridgeInfo
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, HostBridgeInfo<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, HostBridgeInfo<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<HostBridgeInfo<'de>> for HostBridgeInfo
impl<'de> FromWire<HostBridgeInfo<'de>> for HostBridgeInfo
Sourcefn from_wire(wire: HostBridgeInfo<'de>) -> Self
fn from_wire(wire: HostBridgeInfo<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<HostBridgeInfo<'de>> for HostBridgeInfo
impl<'de> FromWireRef<HostBridgeInfo<'de>> for HostBridgeInfo
Sourcefn from_wire_ref(wire: &HostBridgeInfo<'de>) -> Self
fn from_wire_ref(wire: &HostBridgeInfo<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for HostBridgeInfo
impl Hash for HostBridgeInfo
Sourceimpl Ord for HostBridgeInfo
impl Ord for HostBridgeInfo
Sourcefn cmp(&self, other: &HostBridgeInfo) -> Ordering
fn cmp(&self, other: &HostBridgeInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HostBridgeInfo
impl PartialEq for HostBridgeInfo
Sourcefn eq(&self, other: &HostBridgeInfo) -> bool
fn eq(&self, other: &HostBridgeInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HostBridgeInfo
impl PartialOrd for HostBridgeInfo
impl Eq for HostBridgeInfo
impl StructuralPartialEq for HostBridgeInfo