pub struct PciDevice {
pub base_addresses: Vec<BaseAddress>,
pub capabilities: Vec<Capability>,
pub ext_capabilities: Vec<ExtendedCapability>,
pub config: Vec<u8>,
pub bus_id: u8,
pub device_id: u8,
pub function_id: u8,
}Fields
base_addresses: Vec<BaseAddress>capabilities: Vec<Capability>ext_capabilities: Vec<ExtendedCapability>config: Vec<u8>bus_id: u8device_id: u8function_id: u8Trait Implementations
Sourceimpl<'a, ___E> Encode<PciDevice<'static>, ___E> for &'a PciDevicewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PciDevice<'static>, ___E> for &'a PciDevicewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourceimpl<___E> Encode<PciDevice<'static>, ___E> for PciDevicewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PciDevice<'static>, ___E> for PciDevicewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PciDevice<'static>>, ___E> for &'a PciDevice
impl<'a, ___E> EncodeOption<Box<'static, PciDevice<'static>>, ___E> for &'a PciDevice
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PciDevice<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PciDevice<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PciDevice<'static>>, ___E> for PciDevice
impl<___E> EncodeOption<Box<'static, PciDevice<'static>>, ___E> for PciDevice
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PciDevice<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PciDevice<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWireRef<PciDevice<'de>> for PciDevice
impl<'de> FromWireRef<PciDevice<'de>> for PciDevice
Sourcefn from_wire_ref(wire: &PciDevice<'de>) -> Self
fn from_wire_ref(wire: &PciDevice<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PciDevice
impl Ord for PciDevice
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for PciDevice
impl PartialOrd for PciDevice
impl Eq for PciDevice
impl StructuralPartialEq for PciDevice