#[repr(C)]pub struct BaseAddress {
pub address: Uint64,
pub size: Uint64,
pub is_memory: bool,
pub is_prefetchable: bool,
pub is_64bit: bool,
pub id: u8,
}Expand description
The wire type corresponding to BaseAddress.
Fields
address: Uint64size: Uint64is_memory: boolis_prefetchable: boolis_64bit: boolid: u8Trait Implementations
Sourceimpl Clone for BaseAddress
impl Clone for BaseAddress
Sourcefn clone(&self) -> BaseAddress
fn clone(&self) -> BaseAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for BaseAddress
impl Constrained for BaseAddress
Sourceimpl Debug for BaseAddress
impl Debug for BaseAddress
Sourceimpl<___D> Decode<___D> for BaseAddresswhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for BaseAddresswhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<BaseAddress, ___E> for &'a BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BaseAddress, ___E> for &'a BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BaseAddress>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BaseAddress>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BaseAddress, ___E> for BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BaseAddress, ___E> for BaseAddresswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BaseAddress>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BaseAddress>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5> Encode<BaseAddress, ___E> for BaseAddress<T0, T1, T2, T3, T4, T5>
impl<___E, T0, T1, T2, T3, T4, T5> Encode<BaseAddress, ___E> for BaseAddress<T0, T1, T2, T3, T4, T5>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BaseAddress>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BaseAddress>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<BaseAddress> for BaseAddress
impl FromWire<BaseAddress> for BaseAddress
Sourcefn from_wire(wire: BaseAddress) -> Self
fn from_wire(wire: BaseAddress) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<BaseAddress> for BaseAddress
impl FromWireRef<BaseAddress> for BaseAddress
Sourcefn from_wire_ref(wire: &BaseAddress) -> Self
fn from_wire_ref(wire: &BaseAddress) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for BaseAddress
impl IntoNatural for BaseAddress
Sourcetype Natural = BaseAddress
type Natural = BaseAddress
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for BaseAddress
impl Wire for BaseAddress
Sourcetype Narrowed<'de> = BaseAddress
type Narrowed<'de> = BaseAddress
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.