#[repr(C)]pub struct DeviceGetBarRequest {
pub bar_id: Uint32,
}Expand description
The wire type corresponding to DeviceGetBarRequest.
Fields
bar_id: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetBarRequest
impl Clone for DeviceGetBarRequest
Sourcefn clone(&self) -> DeviceGetBarRequest
fn clone(&self) -> DeviceGetBarRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetBarRequest
impl Constrained for DeviceGetBarRequest
Sourceimpl Debug for DeviceGetBarRequest
impl Debug for DeviceGetBarRequest
Sourceimpl<___D> Decode<___D> for DeviceGetBarRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetBarRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetBarRequest, ___E> for &'a DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetBarRequest, ___E> for &'a DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBarRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBarRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetBarRequest, ___E> for DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetBarRequest, ___E> for DeviceGetBarRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBarRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBarRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBarRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBarRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetBarRequest, ___E> for DeviceGetBarRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetBarRequest, ___E> for DeviceGetBarRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBarRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBarRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetBarRequest> for DeviceGetBarRequest
impl FromWire<DeviceGetBarRequest> for DeviceGetBarRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBarRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBarRequest, Self>
Sourcefn from_wire(wire: DeviceGetBarRequest) -> Self
fn from_wire(wire: DeviceGetBarRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetBarRequest> for DeviceGetBarRequest
impl FromWireRef<DeviceGetBarRequest> for DeviceGetBarRequest
Sourcefn from_wire_ref(wire: &DeviceGetBarRequest) -> Self
fn from_wire_ref(wire: &DeviceGetBarRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetBarRequest
impl IntoNatural for DeviceGetBarRequest
Sourcetype Natural = DeviceGetBarRequest
type Natural = DeviceGetBarRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetBarRequest
impl Wire for DeviceGetBarRequest
Sourcetype Narrowed<'de> = DeviceGetBarRequest
type Narrowed<'de> = DeviceGetBarRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.