#[repr(C)]pub struct DeviceGetInterruptModesResponse {
pub modes: InterruptModes,
}Expand description
The wire type corresponding to DeviceGetInterruptModesResponse.
Fields
modes: InterruptModesTrait Implementations
Sourceimpl Clone for DeviceGetInterruptModesResponse
impl Clone for DeviceGetInterruptModesResponse
Sourcefn clone(&self) -> DeviceGetInterruptModesResponse
fn clone(&self) -> DeviceGetInterruptModesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetInterruptModesResponse
impl Constrained for DeviceGetInterruptModesResponse
Sourceimpl<___D> Decode<___D> for DeviceGetInterruptModesResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetInterruptModesResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetInterruptModesResponse, ___E> for &'a DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetInterruptModesResponse, ___E> for &'a DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetInterruptModesResponse, ___E> for DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetInterruptModesResponse, ___E> for DeviceGetInterruptModesResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptModesResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptModesResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetInterruptModesResponse, ___E> for DeviceGetInterruptModesResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<InterruptModes, ___E>,
impl<___E, T0> Encode<DeviceGetInterruptModesResponse, ___E> for DeviceGetInterruptModesResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<InterruptModes, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptModesResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
impl FromWire<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptModesResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptModesResponse, Self>
Sourcefn from_wire(wire: DeviceGetInterruptModesResponse) -> Self
fn from_wire(wire: DeviceGetInterruptModesResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
impl FromWireRef<DeviceGetInterruptModesResponse> for DeviceGetInterruptModesResponse
Sourcefn from_wire_ref(wire: &DeviceGetInterruptModesResponse) -> Self
fn from_wire_ref(wire: &DeviceGetInterruptModesResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetInterruptModesResponse
impl IntoNatural for DeviceGetInterruptModesResponse
Sourcetype Natural = DeviceGetInterruptModesResponse
type Natural = DeviceGetInterruptModesResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetInterruptModesResponse
impl Wire for DeviceGetInterruptModesResponse
Sourcetype Narrowed<'de> = DeviceGetInterruptModesResponse
type Narrowed<'de> = DeviceGetInterruptModesResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.