#[repr(C)]pub struct DeviceReadConfig32Request {
pub offset: Uint16,
}Expand description
The wire type corresponding to DeviceReadConfig32Request.
Fields
offset: Uint16Trait Implementations
Sourceimpl Clone for DeviceReadConfig32Request
impl Clone for DeviceReadConfig32Request
Sourcefn clone(&self) -> DeviceReadConfig32Request
fn clone(&self) -> DeviceReadConfig32Request
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceReadConfig32Request
impl Constrained for DeviceReadConfig32Request
Sourceimpl Debug for DeviceReadConfig32Request
impl Debug for DeviceReadConfig32Request
Sourceimpl<___D> Decode<___D> for DeviceReadConfig32Requestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceReadConfig32Requestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceReadConfig32Request, ___E> for &'a DeviceReadConfig32Requestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig32Request, ___E> for &'a DeviceReadConfig32Requestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Request>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Request>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig32Request, ___E> for DeviceReadConfig32Requestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig32Request, ___E> for DeviceReadConfig32Requestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig32Request>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig32Request>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Request>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Request>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceReadConfig32Request, ___E> for DeviceReadConfig32Request<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
impl<___E, T0> Encode<DeviceReadConfig32Request, ___E> for DeviceReadConfig32Request<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Request>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Request>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceReadConfig32Request> for DeviceReadConfig32Request
impl FromWire<DeviceReadConfig32Request> for DeviceReadConfig32Request
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Request, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Request, Self>
Sourcefn from_wire(wire: DeviceReadConfig32Request) -> Self
fn from_wire(wire: DeviceReadConfig32Request) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig32Request> for DeviceReadConfig32Request
impl FromWireRef<DeviceReadConfig32Request> for DeviceReadConfig32Request
Sourcefn from_wire_ref(wire: &DeviceReadConfig32Request) -> Self
fn from_wire_ref(wire: &DeviceReadConfig32Request) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceReadConfig32Request
impl IntoNatural for DeviceReadConfig32Request
Sourcetype Natural = DeviceReadConfig32Request
type Natural = DeviceReadConfig32Request
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceReadConfig32Request
impl Wire for DeviceReadConfig32Request
Sourcetype Narrowed<'de> = DeviceReadConfig32Request
type Narrowed<'de> = DeviceReadConfig32Request
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.