#[repr(C)]pub struct DeviceReadConfig32Response {
pub value: Uint32,
}Expand description
The wire type corresponding to DeviceReadConfig32Response.
Fields
value: Uint32Trait Implementations
Sourceimpl Clone for DeviceReadConfig32Response
impl Clone for DeviceReadConfig32Response
Sourcefn clone(&self) -> DeviceReadConfig32Response
fn clone(&self) -> DeviceReadConfig32Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceReadConfig32Response
impl Constrained for DeviceReadConfig32Response
Sourceimpl Debug for DeviceReadConfig32Response
impl Debug for DeviceReadConfig32Response
Sourceimpl<___D> Decode<___D> for DeviceReadConfig32Responsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceReadConfig32Responsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceReadConfig32Response, ___E> for &'a DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig32Response, ___E> for &'a DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig32Response, ___E> for DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig32Response, ___E> for DeviceReadConfig32Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig32Response>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig32Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceReadConfig32Response, ___E> for DeviceReadConfig32Response<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceReadConfig32Response, ___E> for DeviceReadConfig32Response<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig32Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig32Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceReadConfig32Response> for DeviceReadConfig32Response
impl FromWire<DeviceReadConfig32Response> for DeviceReadConfig32Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Response, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig32Response, Self>
Sourcefn from_wire(wire: DeviceReadConfig32Response) -> Self
fn from_wire(wire: DeviceReadConfig32Response) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig32Response> for DeviceReadConfig32Response
impl FromWireRef<DeviceReadConfig32Response> for DeviceReadConfig32Response
Sourcefn from_wire_ref(wire: &DeviceReadConfig32Response) -> Self
fn from_wire_ref(wire: &DeviceReadConfig32Response) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceReadConfig32Response
impl IntoNatural for DeviceReadConfig32Response
Sourcetype Natural = DeviceReadConfig32Response
type Natural = DeviceReadConfig32Response
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceReadConfig32Response
impl Wire for DeviceReadConfig32Response
Sourcetype Narrowed<'de> = DeviceReadConfig32Response
type Narrowed<'de> = DeviceReadConfig32Response
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.