#[repr(C)]pub struct DeviceReadConfig8Request {
pub offset: Uint16,
}Expand description
The wire type corresponding to DeviceReadConfig8Request.
Fields
offset: Uint16Trait Implementations
Sourceimpl Clone for DeviceReadConfig8Request
impl Clone for DeviceReadConfig8Request
Sourcefn clone(&self) -> DeviceReadConfig8Request
fn clone(&self) -> DeviceReadConfig8Request
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceReadConfig8Request
impl Constrained for DeviceReadConfig8Request
Sourceimpl Debug for DeviceReadConfig8Request
impl Debug for DeviceReadConfig8Request
Sourceimpl<___D> Decode<___D> for DeviceReadConfig8Requestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceReadConfig8Requestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceReadConfig8Request, ___E> for &'a DeviceReadConfig8Requestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig8Request, ___E> for &'a DeviceReadConfig8Requestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Request>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Request>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig8Request, ___E> for DeviceReadConfig8Requestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig8Request, ___E> for DeviceReadConfig8Requestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig8Request>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig8Request>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Request>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Request>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceReadConfig8Request, ___E> for DeviceReadConfig8Request<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
impl<___E, T0> Encode<DeviceReadConfig8Request, ___E> for DeviceReadConfig8Request<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Request>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Request>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceReadConfig8Request> for DeviceReadConfig8Request
impl FromWire<DeviceReadConfig8Request> for DeviceReadConfig8Request
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Request, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Request, Self>
Sourcefn from_wire(wire: DeviceReadConfig8Request) -> Self
fn from_wire(wire: DeviceReadConfig8Request) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig8Request> for DeviceReadConfig8Request
impl FromWireRef<DeviceReadConfig8Request> for DeviceReadConfig8Request
Sourcefn from_wire_ref(wire: &DeviceReadConfig8Request) -> Self
fn from_wire_ref(wire: &DeviceReadConfig8Request) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceReadConfig8Request
impl IntoNatural for DeviceReadConfig8Request
Sourcetype Natural = DeviceReadConfig8Request
type Natural = DeviceReadConfig8Request
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceReadConfig8Request
impl Wire for DeviceReadConfig8Request
Sourcetype Narrowed<'de> = DeviceReadConfig8Request
type Narrowed<'de> = DeviceReadConfig8Request
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.