#[repr(C)]pub struct DeviceReadConfig8Response {
pub value: u8,
}Expand description
The wire type corresponding to DeviceReadConfig8Response.
Fields
value: u8Trait Implementations
Sourceimpl Clone for DeviceReadConfig8Response
impl Clone for DeviceReadConfig8Response
Sourcefn clone(&self) -> DeviceReadConfig8Response
fn clone(&self) -> DeviceReadConfig8Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceReadConfig8Response
impl Constrained for DeviceReadConfig8Response
Sourceimpl Debug for DeviceReadConfig8Response
impl Debug for DeviceReadConfig8Response
Sourceimpl<___D> Decode<___D> for DeviceReadConfig8Responsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceReadConfig8Responsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceReadConfig8Response, ___E> for &'a DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceReadConfig8Response, ___E> for &'a DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceReadConfig8Response, ___E> for DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceReadConfig8Response, ___E> for DeviceReadConfig8Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig8Response>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceReadConfig8Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceReadConfig8Response, ___E> for DeviceReadConfig8Response<T0>
impl<___E, T0> Encode<DeviceReadConfig8Response, ___E> for DeviceReadConfig8Response<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceReadConfig8Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceReadConfig8Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceReadConfig8Response> for DeviceReadConfig8Response
impl FromWire<DeviceReadConfig8Response> for DeviceReadConfig8Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Response, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceReadConfig8Response, Self>
Sourcefn from_wire(wire: DeviceReadConfig8Response) -> Self
fn from_wire(wire: DeviceReadConfig8Response) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceReadConfig8Response> for DeviceReadConfig8Response
impl FromWireRef<DeviceReadConfig8Response> for DeviceReadConfig8Response
Sourcefn from_wire_ref(wire: &DeviceReadConfig8Response) -> Self
fn from_wire_ref(wire: &DeviceReadConfig8Response) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceReadConfig8Response
impl IntoNatural for DeviceReadConfig8Response
Sourcetype Natural = DeviceReadConfig8Response
type Natural = DeviceReadConfig8Response
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceReadConfig8Response
impl Wire for DeviceReadConfig8Response
Sourcetype Narrowed<'de> = DeviceReadConfig8Response
type Narrowed<'de> = DeviceReadConfig8Response
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.